@@ -35,7 +35,7 @@
 #' Latter arguments are passed to \code{\link[C50]{C5.0Control}}.
 #' Further model details can be found in the source link below.
 #'
-#' In calls to \code{\link{varimp}} for \code{C50Model}, argument \code{metric}
+#' In calls to \code{\link{varimp}} for \code{C50Model}, argument \code{type}
 #' may be specified as \code{"usage"} (default) for the percentage of training
 #' set samples that fall into all terminal nodes after the split of each
 #' predictor or as \code{"splits"} for the percentage of splits associated with
@@ -52,7 +52,7 @@
 #' ## Requires prior installation of suggested package C50 to run
 #'
 #' model_fit <- fit(Species ~ ., data = iris, model = C50Model)
-#' varimp(model_fit, metric = "splits", scale = FALSE)
+#' varimp(model_fit, type = "splits", scale = FALSE)
 #' }
 #'
 C50Model <- function(
@@ -92,8 +92,8 @@ C50Model <- function(
       newdata <- as.data.frame(newdata)
       predict(object, newdata = newdata, type = "prob")
     },
-    varimp = function(object, metric = c("usage", "splits"), ...) {
-      C50::C5imp(object, metric = match.arg(metric))
+    varimp = function(object, type = c("usage", "splits"), ...) {
+      C50::C5imp(object, metric = match.arg(type))
     }
   )
 
