@@ -52,7 +52,7 @@ LocalWarning <- function(...) {
 TypeError <- function(value, expected, subject = character(), call = FALSE) {
   errorCondition(
     message = paste0("Expected ", subject, if (length(subject)) " to be ",
-                     toString(expected, conj = "or"), "; got ", class(value)[1],
+                     toString(expected, conj = "or"), "; got ", class1(value),
                      " instead."),
     call = select_call(call, sys.call(-1)),
     class = "TypeError"
@@ -88,7 +88,7 @@ throw <- function(x, call = TRUE) {
 
 .throw.error <- function(x, call, parent_call, ...) {
   if (match("error", class(x)) > 1) {
-    x$message <- paste0(class(x)[1], ": ", x$message)
+    x$message <- paste0(class1(x), ": ", x$message)
   }
   x$call <- select_call(call, parent_call, conditionCall(x))
   stop(x)
@@ -107,7 +107,7 @@ throw <- function(x, call = TRUE) {
 
 .throw.warning <- function(x, call, parent_call, ...) {
   if (match("warning", class(x)) > 1) {
-    x$message <- paste0(class(x)[1], ": ", x$message)
+    x$message <- paste0(class1(x), ": ", x$message)
   }
   x$call <- select_call(call, parent_call, conditionCall(x))
   warning(x)
@@ -242,7 +242,8 @@ check_metrics <- function(x) {
 
 
 check_numeric <- function(
-  x, bounds = c(-Inf, Inf), include = TRUE, type = c("double", "integer"), ...
+  x, bounds = c(-Inf, Inf), include = TRUE,
+  type = c("numeric", "double", "integer"), ...
 ) {
   result <- check_array(x, type = match.arg(type), ...)
   if (is(result, "error")) {
@@ -272,7 +273,7 @@ check_stat <- function(x) {
 
 
 check_stats <- function(x) {
-  result <- try(list_to_function(x)(1:5), silent = TRUE)
+  result <- try(list_to_function(x, "stat")(1:5), silent = TRUE)
   if (!is.numeric(result)) {
     DomainError(x, "must be a statistics function, function name, ",
                    "or vector of these")
