@@ -2,7 +2,7 @@
 #'
 #' Expand a model over all combinations of a grid of tuning parameters.
 #'
-#' @param x \link[=models]{model} function, function name, or call.
+#' @param x \link[=models]{model} function, function name, or object.
 #' @param ... named vectors or factors or a list of these containing the
 #'   parameter values over which to expand \code{x}.
 #' @param random number of points to be randomly sampled from the parameter grid
@@ -188,12 +188,14 @@ expand_modelgrid.TunedModel <- function(x, ..., info = FALSE) {
   gridinfo <- gridinfo[gridinfo$size >= 1, ]
 
   has_data_arg <- function(fun) "data" %in% names(formals(fun))
-  needs_data <- any(map_logi(has_data_arg, gridinfo$values))
+  needs_data <- any(map_logi(has_data_arg, gridinfo$get_values))
   if (needs_data && has_grid(model)) {
     if (!missing(x)) mf <- ModelFrame(x, ..., na.rm = FALSE)
     if (is.null(mf)) {
       return(NULL)
-    } else if (!is_valid_response(y <- response(mf), model)) {
+    }
+    y <- response(mf)
+    if (!any(is_response(y, model@response_types))) {
       throw(LocalWarning(
         "Invalid model response type in expand_modelgrid().\n",
         "x Exising ", model@name, " supports ",
@@ -206,7 +208,7 @@ expand_modelgrid.TunedModel <- function(x, ..., info = FALSE) {
 
   param_names <- unique(gridinfo$param)
   params <- map(function(fun, n) unique(fun(n = n, data = mf)),
-                gridinfo$values, gridinfo$size)
+                gridinfo$get_values, gridinfo$size)
   params <- map(function(name) {
     unlist(params[gridinfo$param == name], use.names = FALSE)
   }, param_names)
